@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_BINARY_COMPARE_HPP
+#ifndef DEFINE_ISLIB_BINARY_COMPARE_HPP
 
-#define DEFINES_ISLIB_BINARY_COMPARE_HPP
+#define DEFINE_ISLIB_BINARY_COMPARE_HPP
 
 //
 // Inclusion of library header file
@@ -15,7 +15,7 @@ namespace islib
     int binary_compare ( boost::filesystem::path const &, boost::filesystem::path const & );
   }
 
-#endif // DEFINES_ISLIB_BINARY_COMPARE_HPP
+#endif // DEFINE_ISLIB_BINARY_COMPARE_HPP
 
 //
 // End of file
