@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_FATAL_ERROR_HPP
+#ifndef DEFINE_ISLIB_FATAL_ERROR_HPP
 
-#define DEFINES_ISLIB_FATAL_ERROR_HPP
+#define DEFINE_ISLIB_FATAL_ERROR_HPP
 
 namespace islib
   {
@@ -18,8 +18,8 @@ namespace islib
         //
         // Declaration of constructor
         //
-        explicit fatal_error ( char const * ) throw ();
-        fatal_error ( this_type const & ) throw ();
+        explicit fatal_error ( char const * );
+        fatal_error ( this_type const & );
 
         //
         // Declaration of destructor
@@ -27,25 +27,25 @@ namespace islib
         virtual ~fatal_error () throw ();
 
         //
-        // Declaration of operator
+        // Declaration of non-static operator
         //
-        this_type &operator = ( this_type const & ) throw ();
+        this_type &operator = ( this_type const & );
 
         //
-        // Declaration of method
+        // Declaration of non-static member function
         //
         virtual char const *what () const throw ();
         virtual void swap ( this_type & ) throw ();
 
       private:
         //
-        // Declaration of data member
+        // Definition of non-static data member
         //
         char const *message;
       };
   }
 
-#endif // DEFINES_ISLIB_FATAL_ERROR_HPP
+#endif // DEFINE_ISLIB_FATAL_ERROR_HPP
 
 //
 // End of file
