@@ -18,9 +18,9 @@ namespace islib
     // Definition of function
     //
     std::size_t
-    get_number_of_figures
+      get_number_of_figures
       (
-        int const x
+        int x
       )
       {
         class local
@@ -28,29 +28,29 @@ namespace islib
           public:
             local
               (
-                int const x__
+                int const local_x
               )
               {
-                throw_if ( std::invalid_argument ( "islib::get_number_of_figures: x__ == 0" ), x__ == 0 );
+                islib_throw_if_with_message ( std::invalid_argument, islib::get_number_of_figures, local_x == 0 );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
         a_local ( x );
 
-        int x_ = x;
-
-        if ( x_ < 0 )
-          x_ = -x_;
+        if ( x < 0 )
+          x = -x;
 
         std::size_t number_of_figures = 1;
 
-        while ( x_ > static_cast < int > ( std::pow ( 10.0, static_cast < double > ( number_of_figures ) ) ) )
+        while ( x > static_cast < int > ( std::pow ( 10.0, static_cast < double > ( number_of_figures ) ) ) )
           ++number_of_figures;
 
         return number_of_figures;
