@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_GET_NUMBER_OF_FIGURES_HPP
+#ifndef DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP
 
-#define DEFINES_ISLIB_GET_NUMBER_OF_FIGURES_HPP
+#define DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP
 
 //
 // Inclusion of standard header file
@@ -15,7 +15,7 @@ namespace islib
     std::size_t get_number_of_figures ( int );
   }
 
-#endif // DEFINES_ISLIB_GET_NUMBER_OF_FIGURES_HPP
+#endif // DEFINE_ISLIB_GET_NUMBER_OF_FIGURES_HPP
 
 //
 // End of file
