@@ -38,7 +38,7 @@ namespace islib
     // Definition of function
     //
     void
-    link_
+      islib_link
       (
         boost::filesystem::path const &source_file_path,
         boost::filesystem::path const &destination_file_path
@@ -49,18 +49,20 @@ namespace islib
           public:
             local
               (
-                boost::filesystem::path const &source_file_path_,
-                boost::filesystem::path const &destination_file_path_
+                boost::filesystem::path const &local_source_file_path,
+                boost::filesystem::path const &local_destination_file_path
               )
               {
-                throw_if ( std::invalid_argument ( "islib::link_: source_file_path_.empty ()" ), source_file_path_.empty () );
-                throw_if ( std::invalid_argument ( "islib::link_: destination_file_path_.empty ()" ), destination_file_path_.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::local_link, local_source_file_path.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::local_link, local_destination_file_path.empty () );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -74,9 +76,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::link_: link: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_link: link: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -84,7 +86,7 @@ namespace islib
     // Definition of function
     //
     void
-    localtime_r_
+      islib_localtime_r
       (
         std::time_t const * const time,
         struct std::tm * const time_information
@@ -95,18 +97,20 @@ namespace islib
           public:
             local
               (
-                std::time_t const * const time_,
-                struct std::tm * const time_information_
+                std::time_t const * const local_time,
+                struct std::tm * const local_time_information
               )
               {
-                throw_if ( std::invalid_argument ( "islib::localtime_r_: !time_" ), !time_ );
-                throw_if ( std::invalid_argument ( "islib::localtime_r_: !time_information_" ), !time_information_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_localtime_r, !local_time );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_localtime_r, !local_time_information );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -120,9 +124,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::localtime_r_: std::localtime_r: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_localtime_r: std::localtime_r: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -130,7 +134,7 @@ namespace islib
     // Definition of function
     //
     void
-    mkdir_
+      islib_mkdir
       (
         boost::filesystem::path const &directory_path,
         mode_t mode
@@ -141,16 +145,18 @@ namespace islib
           public:
             local
               (
-                boost::filesystem::path const &directory_path_
+                boost::filesystem::path const &local_directory_path
               )
               {
-                throw_if ( std::invalid_argument ( "islib::mkdir_: directory_path_.empty ()" ), directory_path_.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_mkdir, local_directory_path.empty () );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -164,9 +170,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::mkdir_: mkdir: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_mkdir: mkdir: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -174,7 +180,7 @@ namespace islib
     // Definition of function
     //
     void
-    raise_
+      islib_raise
       (
         int const signal_number
       )
@@ -184,16 +190,18 @@ namespace islib
           public:
             local
               (
-                int const signal_number_
+                int const local_signal_number
               )
               {
-                throw_if ( std::invalid_argument ( "islib::raise_: signal_number_ < 1 || _NSIG <= signal_number_" ), signal_number_ < 1 || _NSIG <= signal_number_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_raise, local_signal_number < 1 || _NSIG <= local_signal_number );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -207,9 +215,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::raise_: raise: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_raise: raise: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -217,7 +225,7 @@ namespace islib
     // Definition of function
     //
     void
-    raise_fatal
+      islib_raise_fatal
       (
         int const signal_number
       )
@@ -227,16 +235,18 @@ namespace islib
           public:
             local
               (
-                int const signal_number_
+                int const local_signal_number
               )
               {
-                throw_if ( fatal_error ( "islib::raise_fatal: signal_number_ < 1 || _NSIG <= signal_number_" ), signal_number_ < 1 || _NSIG <= signal_number_ );
+                islib_throw_if_with_message ( fatal_error,  islib::islib_raise_fatal, local_signal_number < 1 || _NSIG <= local_signal_number );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -245,14 +255,14 @@ namespace islib
         int const raise_return_value = raise ( signal_number );
 
         if ( raise_return_value != 0 )
-          throw_ ( fatal_error ( "islib::raise_fatal: raise: fatal error." ) );
+          islib_throw_with_message ( fatal_error, islib::islib_raise_fatal, "raise: fatal error." );
       }
 
     //
     // Definition of function
     //
     void
-    sigaction_
+      islib_sigaction
       (
         int const signal_number,
         struct sigaction const * const signal_action,
@@ -264,18 +274,20 @@ namespace islib
           public:
             local
               (
-                int const signal_number_,
-                struct sigaction const * const signal_action_
+                int const local_signal_number,
+                struct sigaction const * const local_signal_action
               )
               {
-                throw_if ( std::invalid_argument ( "islib::sigaction_: signal_number_ < 1 || _NSIG <= signal_number_" ), signal_number_ < 1 || _NSIG <= signal_number_ );
-                throw_if ( std::invalid_argument ( "islib::sigaction_: !signal_action_" ), !signal_action_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_sigaction, local_signal_number < 1 || _NSIG <= local_signal_number );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_sigaction, !local_signal_action );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -289,9 +301,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::sigaction_: sigaction: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_sigaction: sigaction: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -299,7 +311,7 @@ namespace islib
     // Definition of function
     //
     void
-    sigaction_fatal
+      islib_sigaction_fatal
       (
         int const signal_number,
         struct sigaction const * const signal_action,
@@ -311,18 +323,20 @@ namespace islib
           public:
             local
               (
-                int const signal_number_,
-                struct sigaction const * const signal_action_
+                int const local_signal_number,
+                struct sigaction const * const local_signal_action
               )
               {
-                throw_if ( fatal_error ( "islib::sigaction_fatal: signal_number_ < 1 || _NSIG <= signal_number_" ), signal_number_ < 1 || _NSIG <= signal_number_ );
-                throw_if ( fatal_error ( "islib::sigaction_fatal: !signal_action_" ), !signal_action_ );
+                islib_throw_if_with_message ( fatal_error, islib::islib_sigaction_fatal, local_signal_number < 1 || _NSIG <= local_signal_number );
+                islib_throw_if_with_message ( fatal_error, islib::islib_sigaction_fatal, !local_signal_action );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -331,14 +345,14 @@ namespace islib
         int const sigaction_return_value = sigaction ( signal_number, signal_action, old_signal_action );
 
         if ( sigaction_return_value != 0 )
-          throw_ ( fatal_error ( "islib::sigaction_fatal: sigaction: fatal error." ) );
+          islib_throw_with_message ( fatal_error, islib::islib_sigaction_fatal, "sigaction: fatal error." );
       }
 
     //
     // Definition of function
     //
     void
-    sigfillset_
+      islib_sigfillset
       (
         sigset_t * const signal_set
       )
@@ -348,10 +362,55 @@ namespace islib
           public:
             local
               (
-                sigset_t * const signal_set_
+                sigset_t * const local_signal_set
               )
               {
-                throw_if ( std::invalid_argument ( "islib::sigfillset_: !signal_set_" ), !signal_set_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_sigfillset, !local_signal_set );
+              }
+
+            ~local
+              (
+              )
+              throw
+              (
+              )
+              {
+              }
+          }
+        a_local ( signal_set );
+
+        int const sigfillset_return_value = sigfillset ( signal_set );
+
+        if ( sigfillset_return_value != 0 )
+          {
+            int const saved_errno = errno;
+            char buffer [ BUFSIZ ];
+            std::stringstream system_error_message_stream;
+
+            system_error_message_stream << "islib::islib_sigfillset: sigfillset: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
+          }
+      }
+
+    //
+    // Definition of function
+    //
+    void
+      islib_sigfillset_fatal
+      (
+        sigset_t * const signal_set
+      )
+      {
+        class local
+          {
+          public:
+            local
+              (
+                sigset_t * const local_signal_set
+              )
+              {
+                islib_throw_if_with_message ( fatal_error, islib::islib_sigfillset_fatal, !local_signal_set );
               }
 
             ~local
@@ -366,57 +425,14 @@ namespace islib
         int const sigfillset_return_value = sigfillset ( signal_set );
 
         if ( sigfillset_return_value != 0 )
-          {
-            int const saved_errno = errno;
-            char buffer [ BUFSIZ ];
-            std::stringstream system_error_message_stream;
-
-            system_error_message_stream << "islib::sigfillset_: sigfillset: " << strerror_r ( saved_errno, buffer, BUFSIZ );
-
-            throw_ ( system_error ( system_error_message_stream.str () ) );
-          }
+          islib_throw_with_message ( fatal_error, islib::islib_sigfillset_fatal, "sigfillset: fatal error." );
       }
 
     //
     // Definition of function
     //
     void
-    sigfillset_fatal
-      (
-        sigset_t * const signal_set
-      )
-      {
-        class local
-          {
-          public:
-            local
-              (
-                sigset_t * const signal_set_
-              )
-              {
-                throw_if ( fatal_error ( "islib::sigfillset_fatal: !signal_set_" ), !signal_set_ );
-              }
-
-            ~local
-              ()
-              throw
-                ()
-              {
-              }
-          }
-        a_local ( signal_set );
-
-        int const sigfillset_return_value = sigfillset ( signal_set );
-
-        if ( sigfillset_return_value != 0 )
-          throw_ ( fatal_error ( "islib::sigfillset_fatal: sigfillset: fatal error." ) );
-      }
-
-    //
-    // Definition of function
-    //
-    void
-    sigprocmask_
+      islib_sigprocmask
       (
         int const mode,
         sigset_t const * const signal_set,
@@ -428,18 +444,20 @@ namespace islib
           public:
             local
               (
-                int const mode_,
-                sigset_t const * const signal_set_
+                int const local_mode,
+                sigset_t const * const local_signal_set
               )
               {
-                throw_if ( std::invalid_argument ( "islib::sigprocmask_: mode_ != SIG_BLOCK && mode_ != SIG_UNBLOCK && mode_ != SIG_SETMASK" ), mode_ != SIG_BLOCK && mode_ != SIG_UNBLOCK && mode_ != SIG_SETMASK );
-                throw_if ( std::invalid_argument ( "islib::sigprocmask_: !signal_set_" ), !signal_set_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_sigprocmask, local_mode != SIG_BLOCK && local_mode != SIG_UNBLOCK && local_mode != SIG_SETMASK );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_sigprocmask, !local_signal_set );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -453,9 +471,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::sigprocmask_: sigprocmask: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_sigprocmask: sigprocmask: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -463,7 +481,7 @@ namespace islib
     // Definition of function
     //
     void
-    sigprocmask_fatal
+      islib_sigprocmask_fatal
       (
         int const mode,
         sigset_t const * const signal_set,
@@ -475,18 +493,20 @@ namespace islib
           public:
             local
               (
-                int const mode_,
-                sigset_t const * const signal_set_
+                int const local_mode,
+                sigset_t const * const local_signal_set
               )
               {
-                throw_if ( fatal_error ( "islib::sigprocmask_fatal: mode_ != SIG_BLOCK && mode_ != SIG_UNBLOCK && mode_ != SIG_SETMASK" ), mode_ != SIG_BLOCK && mode_ != SIG_UNBLOCK && mode_ != SIG_SETMASK );
-                throw_if ( fatal_error ( "islib::sigprocmask_fatal_: !signal_set_" ), !signal_set_ );
+                islib_throw_if_with_message ( fatal_error, islib::islib_sigprocmask_fatal, local_mode != SIG_BLOCK && local_mode != SIG_UNBLOCK && local_mode != SIG_SETMASK );
+                islib_throw_if_with_message ( fatal_error, islib::islib_sigprocmask_fatal, !local_signal_set );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -495,14 +515,14 @@ namespace islib
         int const sigprocmask_return_value = sigprocmask ( mode, signal_set, old_signal_set );
 
         if ( sigprocmask_return_value != 0 )
-          throw_ ( fatal_error ( "islib::sigprocmask_fatal: sigprocmask: fatal error." ) );
+          islib_throw_with_message ( fatal_error, islib::islib_sigprocmask_fatal, "sigprocmask: fatal error." );
       }
 
     //
     // Definition of function
     //
     void
-    stat_
+      islib_stat
       (
         boost::filesystem::path const &path,
         struct stat * const status_information
@@ -513,18 +533,20 @@ namespace islib
           public:
             local
               (
-                boost::filesystem::path const &path_,
-                struct stat * const status_information_
+                boost::filesystem::path const &local_path,
+                struct stat * const local_status_information
               )
               {
-                throw_if ( std::invalid_argument ( "islib::stat_: path_.empty ()" ), path_.empty () );
-                throw_if ( std::invalid_argument ( "islib::stat_: !status_information_" ), !status_information_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_stat, local_path.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_stat, !local_status_information );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -538,9 +560,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::stat_: stat: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_stat: stat: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -548,13 +570,13 @@ namespace islib
     // Definition of function
     //
     std::time_t
-    time
+      islib_time
       (
       )
       {
-        std::time_t time_;
+        std::time_t time;
 
-        std::time_t time_return_value = std::time ( &time_ );
+        std::time_t time_return_value = std::time ( &time );
 
         if ( time_return_value == -1 )
           {
@@ -562,19 +584,19 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::time: std::time: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_time: std::time: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
 
-        return time_;
+        return time;
       }
 
     //
     // Definition of function
     //
     void
-    unlink_
+      islib_unlink
       (
         boost::filesystem::path const &file_path
       )
@@ -584,16 +606,18 @@ namespace islib
           public:
             local
               (
-                boost::filesystem::path const &file_path_
+                boost::filesystem::path const &local_file_path
               )
               {
-                throw_if ( std::invalid_argument ( "islib::unlink_: file_path_.empty ()" ), file_path_.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_unlink, local_file_path.empty () );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -607,9 +631,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::unlink_: unlink: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_unlink: unlink: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -617,7 +641,7 @@ namespace islib
     // Definition of function
     //
     void
-    utime_
+      islib_utime
       (
         boost::filesystem::path const &path,
         struct utimbuf const * const utime_information
@@ -628,18 +652,20 @@ namespace islib
           public:
             local
               (
-                boost::filesystem::path const &path_,
-                struct utimbuf const * const utime_information_
+                boost::filesystem::path const &local_path,
+                struct utimbuf const * const local_utime_information
               )
               {
-                throw_if ( std::invalid_argument ( "islib::utime_: path_.empty ()" ), path_.empty () );
-                throw_if ( std::invalid_argument ( "islib::utime_: !utime_information_" ), !utime_information_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_utime, local_path.empty () );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_utime, !local_utime_information );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -653,9 +679,9 @@ namespace islib
             char buffer [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::utime_: utime: " << strerror_r ( saved_errno, buffer, BUFSIZ );
+            system_error_message_stream << "islib::islib_utime: utime: " << strerror_r ( saved_errno, buffer, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -663,7 +689,7 @@ namespace islib
     // Definition of function
     //
     void
-    write_
+      islib_write
       (
         int const file_descriptor,
         void const *buffer,
@@ -675,18 +701,20 @@ namespace islib
           public:
             local
               (
-                int const file_descriptor_,
-                void const *buffer_
+                int const local_file_descriptor,
+                void const *local_buffer
               )
               {
-                throw_if ( std::invalid_argument ( "islib::write_: file_descriptor_ < 0" ), file_descriptor_ < 0 );
-                throw_if ( std::invalid_argument ( "islib::write_: !buffer_" ), !buffer_ );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_write, local_file_descriptor < 0 );
+                islib_throw_if_with_message ( std::invalid_argument, islib::islib_write, !local_buffer );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -700,9 +728,9 @@ namespace islib
             char buffer_ [ BUFSIZ ];
             std::stringstream system_error_message_stream;
 
-            system_error_message_stream << "islib::write_: write: " << strerror_r ( saved_errno, buffer_, BUFSIZ );
+            system_error_message_stream << "islib::islib_write: write: " << strerror_r ( saved_errno, buffer_, BUFSIZ );
 
-            throw_ ( system_error ( system_error_message_stream.str () ) );
+            islib_throw ( system_error ( system_error_message_stream.str () ) );
           }
       }
 
@@ -710,7 +738,7 @@ namespace islib
     // Definition of function
     //
     void
-    write_assert
+      islib_write_assert
       (
         int const file_descriptor,
         void const *buffer,
@@ -722,18 +750,20 @@ namespace islib
           public:
             local
               (
-                int const file_descriptor_,
-                void const *buffer_
+                int const local_file_descriptor,
+                void const *local_buffer
               )
               {
-                throw_if ( fatal_error ( "islib::write_: file_descriptor_ < 0" ), file_descriptor_ < 0 );
-                throw_if ( fatal_error ( "islib::write_: !buffer_" ), !buffer_ );
+                islib_throw_if_with_message ( fatal_error, islib::islib_write_assert, local_file_descriptor < 0 );
+                islib_throw_if_with_message ( fatal_error, islib::islib_write_assert, !local_buffer );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
@@ -741,17 +771,17 @@ namespace islib
 
         ssize_t const write_return_value = write ( file_descriptor, buffer, number_of_bytes );
 
-        assert_ ( write_return_value != -1, "islib::write_: `write_return_value != -1' has failed." );
+        islib_assert_with_message ( write_return_value != -1, islib::islib_write_assert );
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
     template
       <
       >
-    bool
-    equals_to
+      bool
+      equals_to
       <
         double,
         double
@@ -766,13 +796,13 @@ namespace islib
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
     template
       <
       >
-    bool
-    does_not_equal_to
+      bool
+      does_not_equal_to
       <
         double,
         double
@@ -787,13 +817,13 @@ namespace islib
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
     template
       <
       >
-    bool
-    is_less_than
+      bool
+      is_less_than
       <
         double,
         double
@@ -808,13 +838,13 @@ namespace islib
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
     template
       <
       >
-    bool
-    is_greater_than
+      bool
+      is_greater_than
       <
         double,
         double
@@ -829,13 +859,13 @@ namespace islib
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
     template
       <
       >
-    bool
-    is_less_than_or_equals_to
+      bool
+      is_less_than_or_equals_to
       <
         double,
         double
@@ -850,11 +880,13 @@ namespace islib
       }
 
     //
-    // Definition of specialized template function
+    // Definition of specialized function template
     //
-    template <>
-    bool
-    is_greater_than_or_equals_to
+    template
+      <
+      >
+      bool
+      is_greater_than_or_equals_to
       <
         double,
         double
