@@ -17,7 +17,7 @@ namespace islib
     // Definition of function
     //
     double
-    logit
+      logit
       (
         double const x
       )
@@ -27,16 +27,18 @@ namespace islib
           public:
             local
               (
-                double const x_
+                double const local_x
               )
               {
-                throw_if ( std::invalid_argument ( "islib::logit: is_less_than ( x_, 0.0, std::numeric_limits < double >::epsilon () ) || is_greater_than ( x_, 1.0, std::numeric_limits < double >::epsilon () )" ), is_less_than ( x_, 0.0, std::numeric_limits < double >::epsilon () ) || is_greater_than ( x_, 1.0, std::numeric_limits < double >::epsilon () ) );
+                islib_throw_if_with_message ( std::invalid_argument, islib::logit, is_less_than ( local_x, 0.0, std::numeric_limits < double >::epsilon () ) || is_greater_than ( local_x, 1.0, std::numeric_limits < double >::epsilon () ) );
               }
 
             ~local
-              ()
+              (
+              )
               throw
-                ()
+              (
+              )
               {
               }
           }
