@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_LOGIT_HPP
+#ifndef DEFINE_ISLIB_LOGIT_HPP
 
-#define DEFINES_ISLIB_LOGIT_HPP
+#define DEFINE_ISLIB_LOGIT_HPP
 
 namespace islib
   {
@@ -10,7 +10,7 @@ namespace islib
     double logit ( double );
   }
 
-#endif // DEFINES_ISLIB_LOGIT_HPP
+#endif // DEFINE_ISLIB_LOGIT_HPP
 
 //
 // End of file
