@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_NAME_HOLDER_HPP
+#ifndef DEFINE_ISLIB_NAME_HOLDER_HPP
 
-#define DEFINES_ISLIB_NAME_HOLDER_HPP
+#defines DEFINE_ISLIB_NAME_HOLDER_HPP
 
 //
 // Inclusion of standard header file
@@ -16,7 +16,7 @@ namespace islib
       <
         typename Value_Type
       >
-    class name_holder
+      class name_holder
       {
       public:
         //
@@ -39,37 +39,37 @@ namespace islib
         ~name_holder () throw ();
 
         //
-        // Declaration of operator
+        // Declaration of non-static operator
         //
         this_type &operator = ( this_type const & );
         bool operator < ( this_type const & ) const;
 
         //
-        // Declaration of method
+        // Declaration of non-static member function
         //
-        string_type get_name () const;
-        value_type get_value () const;
+        string_type name () const;
+        value_type value () const;
         bool is_null () const;
         void swap ( this_type & ) throw ();
 
         //
-        // Declaration of static method
+        // Declaration of static member function
         //
         string_type replace_name ( string_type const & );
 
       private:
         //
-        // Declaration of data member
+        // Definition of non-static data member
         //
-        string_type name;
-        value_type value;
+        string_type member_name;
+        value_type member_value;
         bool null_flag;
       };
   }
 
 #include "name_holder.ipp"
 
-#endif // DEFINES_ISLIB_NAME_HOLDER_HPP
+#endif // DEFINE_ISLIB_NAME_HOLDER_HPP
 
 //
 // End of file
