@@ -10,9 +10,9 @@ namespace islib
     //
     normal_termination::normal_termination
       (
-        int const exit_status_
+        int const parameter_exit_status
       ):
-      exit_status ( exit_status_ )
+      member_exit_status ( parameter_exit_status )
       {
       }
 
@@ -23,37 +23,37 @@ namespace islib
       (
       )
       throw
-        (
-        )
+      (
+      )
       {
       }
 
     //
-    // Definition of method
+    // Definition of non-static member function
     //
     int
-    normal_termination::get_exit_status
+      normal_termination::exit_status
       (
       )
       const
       throw
-        (
-        )
+      (
+      )
       {
-        return this->exit_status;
+        return this->member_exit_status;
       }
 
     //
-    // Definition of method
+    // Definition of non-static member function
     //
     char const *
-    normal_termination::what
+      normal_termination::what
       (
       )
       const
       throw
-        (
-        )
+      (
+      )
       {
         return 0;
       }
