@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_NORMAL_TERMINATION_HPP
+#ifndef DEFINE_ISLIB_NORMAL_TERMINATION_HPP
 
-#define DEFINES_ISLIB_NORMAL_TERMINATION_HPP
+#define DEFINE_ISLIB_NORMAL_TERMINATION_HPP
 
 //
 // Inclusion of standard header file
@@ -32,20 +32,20 @@ namespace islib
         virtual ~normal_termination () throw ();
 
         //
-        // Declaration of method
+        // Declaration of non-static member function
         //
-        virtual int get_exit_status () const throw ();
+        virtual int exit_status () const throw ();
         virtual char const *what () const throw ();
 
       private:
         //
-        // Declaration of data member
+        // Declaration of non-static data member
         //
-        int exit_status;
+        int member_exit_status;
       };
   }
 
-#endif // DEFINES_ISLIB_NORMAL_TERMINATION_HPP
+#endif // DEFINE_ISLIB_NORMAL_TERMINATION_HPP
 
 //
 // End of file
