@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_COMMAND_PROGRAM_HPP
+#ifndef DEFINE_ISLIB_COMMAND_PROGRAM_HPP
 
-#define DEFINES_ISLIB_COMMAND_PROGRAM_HPP
+#define DEFINE_ISLIB_COMMAND_PROGRAM_HPP
 
 //
 // Inclusion of standard header file
@@ -17,7 +17,7 @@ namespace islib
     void print_error_message ( std::string const & );
   }
 
-#endif // DEFINES_ISLIB_COMMAND_PROGRAM_HPP
+#endif // DEFINE_ISLIB_COMMAND_PROGRAM_HPP
 
 //
 // End of file
