@@ -20,9 +20,9 @@ namespace islib
       {
         sigset_t signal_set;
 
-        sigfillset_fatal ( &signal_set );
+        islib_sigfillset_fatal ( &signal_set );
 
-        sigprocmask_fatal ( SIG_BLOCK, &signal_set, 0 );
+        islib_sigprocmask_fatal ( SIG_BLOCK, &signal_set, 0 );
       }
 
     //
@@ -32,14 +32,14 @@ namespace islib
       (
       )
       throw
-        (
-        )
+      (
+      )
       {
         sigset_t signal_set;
 
-        sigfillset_fatal ( &signal_set );
+        islib_sigfillset_fatal ( &signal_set );
 
-        sigprocmask_fatal ( SIG_UNBLOCK, &signal_set, 0 );
+        islib_sigprocmask_fatal ( SIG_UNBLOCK, &signal_set, 0 );
       }
   }
 
