@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_SIGNAL_BLOCKER_HPP
+#ifndef DEFINE_ISLIB_SIGNAL_BLOCKER_HPP
 
-#define DEFINES_ISLIB_SIGNAL_BLOCKER_HPP
+#define DEFINE_ISLIB_SIGNAL_BLOCKER_HPP
 
 namespace islib
   {
@@ -27,7 +27,7 @@ namespace islib
       };
   }
 
-#endif // DEFINES_ISLIB_SIGNAL_BLOCKER_HPP
+#endif // DEFINE_ISLIB_SIGNAL_BLOCKER_HPP
 
 //
 // End of file
