@@ -1,6 +1,6 @@
-#ifndef DEFINES_ISLIB_SYSTEM_ERROR_HPP
+#ifndef DEFINE_ISLIB_SYSTEM_ERROR_HPP
 
-#define DEFINES_ISLIB_SYSTEM_ERROR_HPP
+#define DEFINE_ISLIB_SYSTEM_ERROR_HPP
 
 //
 // Inclusion of standard header file
@@ -35,7 +35,7 @@ namespace islib
       };
   }
 
-#endif // DEFINES_ISLIB_SYSTEM_ERROR_HPP
+#endif // DEFINE_ISLIB_SYSTEM_ERROR_HPP
 
 //
 // End of file
